@@ -2,9 +2,8 @@
 
 import warnings
 
-JULIA_WARNING = (
-    "Julia not installed, Extreme Value Analysis functionalities will be disabled."
-)
+
+JULIA_WARNING = "Julia not installed, Extreme Value Analysis functionalities will be disabled."
 
 try:
     from .julia_import import Extremes, jl
@@ -13,6 +12,6 @@ try:
     __all__ = ["Extremes", "fit", "jl", "return_level"]
 
 except ImportError:
-    warnings.warn(JULIA_WARNING)
+    warnings.warn(JULIA_WARNING, stacklevel=2)
 
     __all__ = ["JULIA_WARNING"]
