@@ -43,30 +43,17 @@ def major_precipitation_events(
     https://doi.org/10.1016/j.ejrh.2017.07.003
     """
     events = xr.concat(
-        [
-            da.rolling({"time": window}, center=False)
-            .sum(keep_attrs=True)
-            .assign_coords({"window": window})
-            for window in windows
-        ],
+        [da.rolling({"time": window}, center=False).sum(keep_attrs=True).assign_coords({"window": window}) for window in windows],
         dim="window",
     )
 
     if quantile is not None:
-        events = (
-            events.chunk(dict(time=-1))
-            .groupby("time.year")
-            .map(_keep_highest_values, quantile=quantile)
-        )
+        events = events.chunk(dict(time=-1)).groupby("time.year").map(_keep_highest_values, quantile=quantile)
         events.attrs["long_name"] = "Major precipitation events"
-        events.attrs["description"] = (
-            f"Top {quantile * 100}% of the accumulated precipitation over the specified number of time steps."
-        )
+        events.attrs["description"] = f"Top {quantile * 100}% of the accumulated precipitation over the specified number of time steps."
     else:
         events.attrs["long_name"] = "Precipitation events"
-        events.attrs["description"] = (
-            f"Precipitation events for the accumulation of the given number of time steps."
-        )
+        events.attrs["description"] = "Precipitation events for the accumulation of the given number of time steps."
 
     # Add attributes
     events.name = "precipitation_events"
@@ -148,9 +135,7 @@ def precipitable_water(
     zg = units.convert_units_to(zg, "m")
     orog = units.convert_units_to(orog, "m")
     if hus.attrs.get("units") not in ["1", "", "kg kg-1", "kg/kg"]:
-        warnings.warn(
-            "Specific humidity units does not appear to be in kg/kg. Results may be incorrect."
-        )
+        warnings.warn("Specific humidity units does not appear to be in kg/kg. Results may be incorrect.", stacklevel=2)
 
     # Correction of the first zone above the topography to consider the correct fraction.
     da = zg - orog
@@ -191,17 +176,10 @@ def precipitable_water(
 
     # Compute the precipitable water for the given window.
     out = xr.concat(
-        [
-            pw.rolling({"time": window + 1}, center=False)
-            .max(keep_attrs=True)
-            .assign_coords({"window": window})
-            for window in windows
-        ],
+        [pw.rolling({"time": window + 1}, center=False).max(keep_attrs=True).assign_coords({"window": window}) for window in windows],
         dim="window",
     )
-    out["window"].attrs = {
-        "description": "Duration of the event, including antecedent conditions (window + 1)."
-    }
+    out["window"].attrs = {"description": "Duration of the event, including antecedent conditions (window + 1)."}
 
     return out
 
@@ -215,7 +193,8 @@ def precipitable_water_100y(
     n: int | None = None,
     rebuild_time: bool = True,
 ):
-    """Compute the 100-year return period of precipitable water for each month. Based on Clavet-Gaumont et al. (2017).
+    """
+    Compute the 100-year return period of precipitable water for each month. Based on Clavet-Gaumont et al. (2017).
 
     Parameters
     ----------
@@ -287,6 +266,7 @@ def precipitable_water_100y(
                 for y, m in zip(
                     pw100_m.year.values,
                     pw100_m.month.values,
+                    strict=False,
                 )
             ]
         else:
@@ -294,18 +274,12 @@ def precipitable_water_100y(
 
         pw100_m = pw100_m.assign_coords(time=("stacked_coords", time_coord))
         pw100_m = pw100_m.swap_dims({"stacked_coords": "time"}).sortby("time")
-        pw100_m = (
-            pw100_m.reindex_like(pw)
-            .ffill(dim="time")
-            .drop_vars(["month", "year", "stacked_coords"])
-        )
+        pw100_m = pw100_m.reindex_like(pw).ffill(dim="time").drop_vars(["month", "year", "stacked_coords"])
 
         # Set NaN for months where pw100_m is missing. This occurs when working with solid precipitation
         def _mask_pw100_by_zero_count(pw_v, count_v, time_months):
             # Get zero-count months
-            zero_months = (
-                np.where(count_v == 0)[0] + 1
-            )  # assuming month index is 0-based
+            zero_months = np.where(count_v == 0)[0] + 1  # assuming month index is 0-based
             return np.where(np.isin(time_months, zero_months), np.nan, pw_v)
 
         pw100_m = xr.apply_ufunc(
@@ -335,7 +309,8 @@ def compute_spring_and_summer_mask(
     spr_end: int = 30,
     freq: str = "YS-JUL",
 ):
-    """Create a mask that defines the spring and summer seasons based on the snow water equivalent.
+    """
+    Create a mask that defines the spring and summer seasons based on the snow water equivalent.
 
     Parameters
     ----------
@@ -366,14 +341,10 @@ def compute_spring_and_summer_mask(
     snw.attrs.update(attrs)
     snw.attrs["units"] = "mm"
 
-    winter_start = xclim.indices.snd_season_start(
-        snd=snw, thresh=thresh, window=window_wint_start, freq=freq
-    )
+    winter_start = xclim.indices.snd_season_start(snd=snw, thresh=thresh, window=window_wint_start, freq=freq)
     first_day = int(winter_start.time.dt.dayofyear[0])
     if first_day < 182:
-        raise NotImplementedError(
-            "Frequencies starting before July 1st are not yet supported."
-        )
+        raise NotImplementedError("Frequencies starting before July 1st are not yet supported.")
 
     # Summer ends when winter starts, or at the end of the year
     summer_end = (
@@ -387,42 +358,25 @@ def compute_spring_and_summer_mask(
     # YS-JUL and similar freqs shifts the start by a year. Since we are looking for dates in spring and summer, we need to add a year.
     winter_start = winter_start.assign_coords({"year": winter_start.time.dt.year + 1})
     winter_start = winter_start.swap_dims({"time": "year"}).drop_vars("time")
-    winter_start = winter_start.sel(
-        year=slice(min(snw.time.dt.year), max(snw.time.dt.year))
-    )  # The last year is not complete
+    winter_start = winter_start.sel(year=slice(min(snw.time.dt.year), max(snw.time.dt.year)))  # The last year is not complete
     mask = xr.where(winter_start.isnull(), np.nan, 1)
-    winter_start = (
-        winter_start.where(winter_start <= first_day, 1) * mask
-    )  # Set to 1 where winter started before January 1st
+    winter_start = winter_start.where(winter_start <= first_day, 1) * mask  # Set to 1 where winter started before January 1st
 
     winter_end = (
-        xclim.indices.snd_season_end(
-            snd=snw, thresh=thresh, window=window_wint_end, freq=freq
-        )
-        - 1
+        xclim.indices.snd_season_end(snd=snw, thresh=thresh, window=window_wint_end, freq=freq) - 1
     )  # xclim gives the first day without snow, we want the last day with snow
-    winter_end = winter_end.where(
-        winter_end < first_day - 2
-    )  # If winter never ends, xclim gives the last day of the year
+    winter_end = winter_end.where(winter_end < first_day - 2)  # If winter never ends, xclim gives the last day of the year
 
     winter_end = winter_end.assign_coords({"year": winter_end.time.dt.year + 1})
     winter_end = winter_end.swap_dims({"time": "year"}).drop_vars("time")
-    winter_end = winter_end.sel(
-        year=slice(min(snw.time.dt.year), max(snw.time.dt.year))
-    )  # The last year is not complete
-    winter_end = xr.where(
-        winter_end >= first_day, 1, winter_end
-    )  # If winter ends the autumn before, set to 1
+    winter_end = winter_end.sel(year=slice(min(snw.time.dt.year), max(snw.time.dt.year)))  # The last year is not complete
+    winter_end = xr.where(winter_end >= first_day, 1, winter_end)  # If winter ends the autumn before, set to 1
 
     # Sanity check
     if (winter_end.isnull() & winter_start.notnull()).any():
-        raise ValueError(
-            "Winter starts but never ends. Check your `freq` or `window` parameters."
-        )
+        raise ValueError("Winter starts but never ends. Check your `freq` or `window` parameters.")
 
-    winter_end = winter_end.where(
-        winter_end < summer_end, summer_end - 1
-    )  # Winter can't end after summer
+    winter_end = winter_end.where(winter_end < summer_end, summer_end - 1)  # Winter can't end after summer
     mask = xr.where(winter_start.isnull(), np.nan, 1)
     winter_end = winter_end * mask
 
@@ -441,20 +395,8 @@ def compute_spring_and_summer_mask(
         year_mask = (group.time.dt.dayofyear >= s) & (group.time.dt.dayofyear <= e)
         return year_mask
 
-    summer_mask = (
-        xr.zeros_like(snw)
-        .groupby("time.year")
-        .map(_create_mask, start=summer_start, end=summer_end)
-        .drop_vars("year")
-        .astype(int)
-    )
-    spring_mask = (
-        xr.zeros_like(snw)
-        .groupby("time.year")
-        .map(_create_mask, start=spring_start, end=spring_end)
-        .drop_vars("year")
-        .astype(int)
-    )
+    summer_mask = xr.zeros_like(snw).groupby("time.year").map(_create_mask, start=summer_start, end=summer_end).drop_vars("year").astype(int)
+    spring_mask = xr.zeros_like(snw).groupby("time.year").map(_create_mask, start=spring_start, end=spring_end).drop_vars("year").astype(int)
 
     summer_mask.name = "mask_summer"
     summer_mask.attrs = {
@@ -485,7 +427,8 @@ def compute_spring_and_summer_mask(
 
 
 def spatial_average_storm_configurations(da, *, radius):
-    """Compute the spatial average for different storm configurations proposed by Clavet-Gaumont et al. (2017).
+    """
+    Compute the spatial average for different storm configurations proposed by Clavet-Gaumont et al. (2017).
 
     Parameters
     ----------
@@ -628,13 +571,12 @@ def spatial_average_storm_configurations(da, *, radius):
     r_max = dy * max(dict_config["24.2"][0]) / 2
     if r_max < radius:
         warnings.warn(
-            f"The chosen `radius` exceeds the maximum storm radius that can be calculated. As a result, the maximum storm radius will be {r_max}."
+            f"The chosen `radius` exceeds the maximum storm radius that can be calculated. As a result, the maximum storm radius will be {r_max}.",
+            stacklevel=2,
         )
 
     if (dy > radius) or (dx > radius):
-        raise ValueError(
-            "The chosen `radius` is smaller than the grid size. Please choose a larger `radius`."
-        )
+        raise ValueError("The chosen `radius` is smaller than the grid size. Please choose a larger `radius`.")
 
     # Number of pixels in da
     npy_da = len(da[y])
@@ -643,7 +585,6 @@ def spatial_average_storm_configurations(da, *, radius):
     da_stacked = da.stack(stacked_coords=("y", "x"))
     confi_lst = []
     for name, confi in dict_config.items():
-
         conf_y = confi[0]
         conf_x = confi[1]
 
@@ -680,7 +621,6 @@ def spatial_average_storm_configurations(da, *, radius):
 
         list_mean = []
         for confi_shifted in shifted_confi:
-
             matrix_mask = np.full((len(da[y]), len(da[x])), np.nan)
 
             cen_shift_y = (min(confi_shifted[0]) + max(confi_shifted[0])) // 2
@@ -768,9 +708,7 @@ def pw_snowfall(
         raise ValueError("Both 'prsn_events' and 'prsn_threshold ' must be provided.")
 
     if method in ["m1", "m3"] and (prra_events is None or prra_threshold is None):
-        raise ValueError(
-            f"'prra_events' and 'prra_threshold' are required for method '{method}'."
-        )
+        raise ValueError(f"'prra_events' and 'prra_threshold' are required for method '{method}'.")
 
     if method == "m3" and pr_events is None:
         raise ValueError("'pr_events' is required for method 'm3'.")
@@ -781,34 +719,24 @@ def pw_snowfall(
         rf_threshold_converted = units.convert_units_to(prra_threshold, prra_events)
 
     if method == "m1":
-        pw_snowfall = pw.where(
-            (prra_events < rf_threshold_converted)
-            & (prsn_events > prsn_threshold_converted)
-        )
+        pw_snowfall = pw.where((prra_events < rf_threshold_converted) & (prsn_events > prsn_threshold_converted))
     elif method == "m2":
         pw_snowfall = pw.where(prsn_events > prsn_threshold_converted)
     elif method == "m3":
-
         if prsn_events.attrs.get("units") != pr_events.attrs.get("units"):
-            raise ValueError(f"`prsn_events`and `pr_events` must have the same units.")
+            raise ValueError("`prsn_events`and `pr_events` must have the same units.")
         else:
             pw_snowfall_m2 = pw.where(prsn_events > prsn_threshold_converted)
-            where_m3 = (prsn_events > prsn_threshold_converted) & (
-                prra_events > rf_threshold_converted
-            )
+            where_m3 = (prsn_events > prsn_threshold_converted) & (prra_events > rf_threshold_converted)
             ratio_snowfall = prsn_events / pr_events
-            pw_snowfall = xr.where(
-                where_m3, pw_snowfall_m2 * ratio_snowfall, pw_snowfall_m2
-            )
+            pw_snowfall = xr.where(where_m3, pw_snowfall_m2 * ratio_snowfall, pw_snowfall_m2)
             pw_snowfall.attrs["units"] = pw_snowfall_m2.attrs["units"]
     else:
         raise ValueError(f"Invalid method '{method}'. Choose from ['m1', 'm2', 'm3'].")
 
-    pw_snowfall.name = f"precipitable_water_snowfall"
+    pw_snowfall.name = "precipitable_water_snowfall"
     pw_snowfall.attrs["method"] = method
-    pw_snowfall.attrs["long_name"] = (
-        "Precipitable water associated with snowfall events."
-    )
+    pw_snowfall.attrs["long_name"] = "Precipitable water associated with snowfall events."
     pw_snowfall.attrs["description"] = (
         f"Estimated precipitable water associated with snowfall events using method {method}, based on Klein et al. (2017): https://doi.org/10.1016/j.jhydrol.2016.03.031."
     )
