@@ -10,7 +10,6 @@ from xhydro.optimal_interpolation.ECF_climate_correction import general_ecf
 
 
 class TestOptimalInterpolationIntegrationCorrectedFiles:
-
     # Start and end dates for the simulation. Short period for the test.
     start_date = dt.datetime(2018, 11, 1)
     end_date = dt.datetime(2019, 1, 1)
@@ -28,16 +27,8 @@ class TestOptimalInterpolationIntegrationCorrectedFiles:
     def test_cross_validation_execute(self, corrected_oi_data):
         """Test the cross validation of optimal interpolation."""
         # Get the required times only
-        qobs = (
-            corrected_oi_data["qobs"]
-            .sel(time=slice(self.start_date, self.end_date))
-            .rename({"streamflow": "q"})
-        )
-        qsim = (
-            corrected_oi_data["qsim"]
-            .sel(time=slice(self.start_date, self.end_date))
-            .rename({"streamflow": "q"})
-        )
+        qobs = corrected_oi_data["qobs"].sel(time=slice(self.start_date, self.end_date)).rename({"streamflow": "q"})
+        qsim = corrected_oi_data["qsim"].sel(time=slice(self.start_date, self.end_date)).rename({"streamflow": "q"})
 
         # Run the code and obtain the resulting flows.
         ds = opt.execute_interpolation(
@@ -75,12 +66,8 @@ class TestOptimalInterpolationIntegrationCorrectedFiles:
         end_date = dt.datetime(2018, 12, 31)
 
         ds = opt.execute_interpolation(
-            corrected_oi_data["qobs"]
-            .sel(time=slice(start_date, end_date))
-            .rename({"streamflow": "q"}),
-            corrected_oi_data["qsim"]
-            .sel(time=slice(start_date, end_date))
-            .rename({"streamflow": "q"}),
+            corrected_oi_data["qobs"].sel(time=slice(start_date, end_date)).rename({"streamflow": "q"}),
+            corrected_oi_data["qsim"].sel(time=slice(start_date, end_date)).rename({"streamflow": "q"}),
             corrected_oi_data["station_correspondence"],
             corrected_oi_data["observation_stations"],
             ratio_var_bg=self.ratio_var_bg,
@@ -109,19 +96,13 @@ class TestOptimalInterpolationIntegrationCorrectedFiles:
         assert len(ds["time"].data) == (end_date - start_date).days + 1
 
     # FIXME: Not sure what's going on here. This test is failing on conda-forge.
-    @pytest.mark.xfail(
-        reason="test reports that num processes is not more than one on conda-forge."
-    )
+    @pytest.mark.xfail(reason="test reports that num processes is not more than one on conda-forge.")
     def test_cross_validation_execute_parallel(self, corrected_oi_data):
         """Test the parallel version of the optimal interpolation cross validation."""
         # Run the interpolation and obtain the resulting flows.
         ds = opt.execute_interpolation(
-            corrected_oi_data["qobs"]
-            .sel(time=slice(self.start_date, self.end_date))
-            .rename({"streamflow": "q"}),
-            corrected_oi_data["qsim"]
-            .sel(time=slice(self.start_date, self.end_date))
-            .rename({"streamflow": "q"}),
+            corrected_oi_data["qobs"].sel(time=slice(self.start_date, self.end_date)).rename({"streamflow": "q"}),
+            corrected_oi_data["qsim"].sel(time=slice(self.start_date, self.end_date)).rename({"streamflow": "q"}),
             corrected_oi_data["station_correspondence"],
             corrected_oi_data["observation_stations"],
             ratio_var_bg=self.ratio_var_bg,
@@ -153,12 +134,8 @@ class TestOptimalInterpolationIntegrationCorrectedFiles:
         """Test the operational version of the optimal interpolation code."""
         # Run the interpolation and get flows
         ds = opt.execute_interpolation(
-            corrected_oi_data["qobs"]
-            .sel(time=slice(self.start_date, self.end_date))
-            .rename({"streamflow": "q"}),
-            corrected_oi_data["qsim"]
-            .sel(time=slice(self.start_date, self.end_date))
-            .rename({"streamflow": "q"}),
+            corrected_oi_data["qobs"].sel(time=slice(self.start_date, self.end_date)).rename({"streamflow": "q"}),
+            corrected_oi_data["qsim"].sel(time=slice(self.start_date, self.end_date)).rename({"streamflow": "q"}),
             corrected_oi_data["station_correspondence"],
             corrected_oi_data["observation_stations"],
             ratio_var_bg=self.ratio_var_bg,
@@ -191,15 +168,9 @@ class TestOptimalInterpolationIntegrationCorrectedFiles:
         end_date = dt.datetime(2018, 12, 30)
 
         cr.compare(
-            qobs=corrected_oi_data["qobs"]
-            .sel(time=slice(start_date, end_date))
-            .rename({"streamflow": "q"}),
-            qsim=corrected_oi_data["qsim"]
-            .sel(time=slice(start_date, end_date))
-            .rename({"streamflow": "q"}),
-            flow_l1o=corrected_oi_data["flow_l1o"]
-            .sel(time=slice(start_date, end_date))
-            .rename({"streamflow": "q"}),
+            qobs=corrected_oi_data["qobs"].sel(time=slice(start_date, end_date)).rename({"streamflow": "q"}),
+            qsim=corrected_oi_data["qsim"].sel(time=slice(start_date, end_date)).rename({"streamflow": "q"}),
+            flow_l1o=corrected_oi_data["flow_l1o"].sel(time=slice(start_date, end_date)).rename({"streamflow": "q"}),
             station_correspondence=corrected_oi_data["station_correspondence"],
             observation_stations=corrected_oi_data["observation_stations"],
             show_comparison=False,
@@ -208,16 +179,8 @@ class TestOptimalInterpolationIntegrationCorrectedFiles:
     def test_optimal_interpolation_single_time_dim(self, corrected_oi_data):
         """Test the OI for data with no time dimension such as indicators."""
         # Get the required times only
-        qobs = (
-            corrected_oi_data["qobs"]
-            .sel(time=dt.datetime(2018, 12, 20))
-            .rename({"streamflow": "q"})
-        )
-        qsim = (
-            corrected_oi_data["qsim"]
-            .sel(time=dt.datetime(2018, 12, 20))
-            .rename({"streamflow": "q"})
-        )
+        qobs = corrected_oi_data["qobs"].sel(time=dt.datetime(2018, 12, 20)).rename({"streamflow": "q"})
+        qsim = corrected_oi_data["qsim"].sel(time=dt.datetime(2018, 12, 20)).rename({"streamflow": "q"})
 
         # TODO: Generate better data to make sure results compute accurately
         # Run the code and ensure dataset is of correct size and code does not crash.
@@ -244,18 +207,8 @@ class TestOptimalInterpolationIntegrationCorrectedFiles:
     def test_optimal_interpolation_no_time_dim(self, corrected_oi_data):
         """Test the OI for data with no time dimension such as indicators."""
         # Get the required times only
-        qobs = (
-            corrected_oi_data["qobs"]
-            .isel(time=10)
-            .drop_vars("time")
-            .rename({"streamflow": "q"})
-        )
-        qsim = (
-            corrected_oi_data["qsim"]
-            .isel(time=10)
-            .drop_vars("time")
-            .rename({"streamflow": "q"})
-        )
+        qobs = corrected_oi_data["qobs"].isel(time=10).drop_vars("time").rename({"streamflow": "q"})
+        qsim = corrected_oi_data["qsim"].isel(time=10).drop_vars("time").rename({"streamflow": "q"})
 
         # TODO: Generate better data to make sure results compute accurately
         # Run the code and ensure dataset is of correct size and code does not crash.
@@ -281,7 +234,6 @@ class TestOptimalInterpolationIntegrationCorrectedFiles:
 
 
 class TestOptimalInterpolationIntegrationOriginalDEHFiles:
-
     # Start and end dates for the simulation. Short period for the test.
     start_date = dt.datetime(2018, 11, 1)
     end_date = dt.datetime(2019, 1, 1)
@@ -299,16 +251,8 @@ class TestOptimalInterpolationIntegrationOriginalDEHFiles:
     def test_cross_validation_execute(self, oi_data):
         """Test the cross validation of optimal interpolation."""
         # Get the required times only
-        qobs = (
-            oi_data["qobs"]
-            .sel(time=slice(self.start_date, self.end_date))
-            .rename({"streamflow": "q"})
-        )
-        qsim = (
-            oi_data["qsim"]
-            .sel(time=slice(self.start_date, self.end_date))
-            .rename({"streamflow": "q"})
-        )
+        qobs = oi_data["qobs"].sel(time=slice(self.start_date, self.end_date)).rename({"streamflow": "q"})
+        qsim = oi_data["qsim"].sel(time=slice(self.start_date, self.end_date)).rename({"streamflow": "q"})
 
         # Run the code and obtain the resulting flows.
         ds = opt.execute_interpolation(
@@ -346,12 +290,8 @@ class TestOptimalInterpolationIntegrationOriginalDEHFiles:
         end_date = dt.datetime(2018, 12, 31)
 
         ds = opt.execute_interpolation(
-            oi_data["qobs"]
-            .sel(time=slice(start_date, end_date))
-            .rename({"streamflow": "q"}),
-            oi_data["qsim"]
-            .sel(time=slice(start_date, end_date))
-            .rename({"streamflow": "q"}),
+            oi_data["qobs"].sel(time=slice(start_date, end_date)).rename({"streamflow": "q"}),
+            oi_data["qsim"].sel(time=slice(start_date, end_date)).rename({"streamflow": "q"}),
             oi_data["station_correspondence"],
             oi_data["observation_stations"],
             ratio_var_bg=self.ratio_var_bg,
@@ -380,19 +320,13 @@ class TestOptimalInterpolationIntegrationOriginalDEHFiles:
         assert len(ds["time"].data) == (end_date - start_date).days + 1
 
     # FIXME: Not sure what's going on here. This test is failing on conda-forge.
-    @pytest.mark.xfail(
-        reason="test reports that num processes is not more than one on conda-forge."
-    )
+    @pytest.mark.xfail(reason="test reports that num processes is not more than one on conda-forge.")
     def test_cross_validation_execute_parallel(self, oi_data):
         """Test the parallel version of the optimal interpolation cross validation."""
         # Run the interpolation and get flows
         ds = opt.execute_interpolation(
-            oi_data["qobs"]
-            .sel(time=slice(self.start_date, self.end_date))
-            .rename({"streamflow": "q"}),
-            oi_data["qsim"]
-            .sel(time=slice(self.start_date, self.end_date))
-            .rename({"streamflow": "q"}),
+            oi_data["qobs"].sel(time=slice(self.start_date, self.end_date)).rename({"streamflow": "q"}),
+            oi_data["qsim"].sel(time=slice(self.start_date, self.end_date)).rename({"streamflow": "q"}),
             oi_data["station_correspondence"],
             oi_data["observation_stations"],
             ratio_var_bg=self.ratio_var_bg,
@@ -425,15 +359,9 @@ class TestOptimalInterpolationIntegrationOriginalDEHFiles:
         end_date = dt.datetime(2018, 12, 30)
 
         cr.compare(
-            qobs=oi_data["qobs"]
-            .sel(time=slice(start_date, end_date))
-            .rename({"streamflow": "q"}),
-            qsim=oi_data["qsim"]
-            .sel(time=slice(start_date, end_date))
-            .rename({"streamflow": "q"}),
-            flow_l1o=oi_data["flow_l1o"]
-            .sel(time=slice(start_date, end_date))
-            .rename({"streamflow": "q"}),
+            qobs=oi_data["qobs"].sel(time=slice(start_date, end_date)).rename({"streamflow": "q"}),
+            qsim=oi_data["qsim"].sel(time=slice(start_date, end_date)).rename({"streamflow": "q"}),
+            flow_l1o=oi_data["flow_l1o"].sel(time=slice(start_date, end_date)).rename({"streamflow": "q"}),
             station_correspondence=oi_data["station_correspondence"],
             observation_stations=oi_data["observation_stations"],
             show_comparison=False,
@@ -469,12 +397,6 @@ class TestEcfFunctions:
         param = np.array([0.5, 50])
 
         # Test the three forms for the general_ecf function
-        assert np.allclose(
-            general_ecf(h, param, form=1), np.array([0.5, 0.49990132, 0.49961051])
-        )
-        assert np.allclose(
-            general_ecf(h, param, form=2), np.array([0.5, 0.49990001, 0.49960016])
-        )
-        assert np.allclose(
-            general_ecf(h, param, form=3), np.array([0.5, 0.49009934, 0.48039472])
-        )
+        assert np.allclose(general_ecf(h, param, form=1), np.array([0.5, 0.49990132, 0.49961051]))
+        assert np.allclose(general_ecf(h, param, form=2), np.array([0.5, 0.49990001, 0.49960016]))
+        assert np.allclose(general_ecf(h, param, form=3), np.array([0.5, 0.49009934, 0.48039472]))
