@@ -3,4 +3,4 @@ import xhydro as xh
 
 # Smoke test for xscen functions that are imported into xhydro
 def test_xscen_imported():
-    assert callable(getattr(xh.utils, "health_checks"))
+    assert callable(xh.utils.health_checks)
